@@ -1,7 +1,7 @@
 __all__ = ("get_raw_pkg", "groupby_pkg")
 
 import itertools
-import operator
+from operator import attrgetter
 
 
 def get_raw_pkg(pkg):
@@ -10,7 +10,7 @@ def get_raw_pkg(pkg):
         p = p._raw_pkg
     return p
 
-groupby_key_getter = operator.attrgetter("key")
+
 def groupby_pkg(iterable):
-    for key, pkgs in itertools.groupby(iterable, groupby_key_getter):
+    for key, pkgs in itertools.groupby(iterable, attrgetter('key')):
         yield pkgs
